@@ -1325,17 +1325,19 @@ class Client(commandServer, encrypt, Desktop):
         remoteProfile = "::profile/{}".format(profileName)
         if not self.syncUserNew(ps, uid, gid, homeDir, "login",
                                 remoteProfile, host=host):
-            if re.search(r'\[sender\] change_dir "{resPath}" \(in {resName}\) '
+            error_output = ps.output
+            if re.search(r'change_dir "\?{resPath}" \(in {resName}\) '
                 'failed: No such file or directory'.format(
                     resPath=profileName,
-                    resName="profile"), ps.output):
+                    resName="profile"), error_output) or \
+                    not ps.exists(remoteProfile):
                 if clearHomeDir:
                     # clean home directory
                     if not self.clearHomeDir(homeDir):
                         return False
                 return True
             else:
-                self.printERROR(ps.output)
+                self.printERROR(error_output)
                 self.printERROR(_("Failed to execute rsync"))
                 return False
         return True
